@@ -2,11 +2,13 @@ import logging
 
 logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(levelname)s - %(message)s')
 logger = logging.getLogger(__name__)
-logger.setLevel(logging.INFO)  # Set the log level
+#logger.setLevel(logging.INFO)  # Set the log level
+logger.setLevel(logging.DEBUG)  # Set the log level
 
 # Create a console handler and set its level and format
 console_handler = logging.StreamHandler()
-console_handler.setLevel(logging.INFO)
+#console_handler.setLevel(logging.INFO)
+console_handler.setLevel(logging.DEBUG)
 formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
 
 console_handler.setFormatter(formatter)
