@@ -164,6 +164,10 @@ def celltype_density(
 
     density.X = density.X / np.array(density.obs['ROI_area'])[:, None]
     
+    for cond in condition_keys:
+        if data.uns[f'{cond}_colors']:
+            density.uns[f'{cond}_colors'] = data.uns[f'{cond}_colors']
+    
     return density
 
 def impute_roi_area(
